[PATCH v1 1/1] gpio: tps65214: Add support for TI TPS65214 PMIC

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Add TPS65214 support to platform_id table and device-specific chip_data
struct. Update descriptions to reflect the driver supports 3 PMICs:
TPS65214, TPS65215, and TPS65219.

Signed-off-by: Shree Ramamoorthy <s-ramamoorthy@xxxxxx>
---
 drivers/gpio/gpio-tps65219.c | 9 +++++++--
 1 file changed, 7 insertions(+), 2 deletions(-)

diff --git a/drivers/gpio/gpio-tps65219.c b/drivers/gpio/gpio-tps65219.c
index 6845f2920f3a..6b8d88ca3e8a 100644
--- a/drivers/gpio/gpio-tps65219.c
+++ b/drivers/gpio/gpio-tps65219.c
@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 /*
  * GPIO driver for TI TPS65215/TPS65219 PMICs
  *
  * Copyright (C) 2024 Texas Instruments Incorporated - http://www.ti.com/
  */
@@ -156,6 +156,10 @@ static const struct gpio_chip tps65219_template_chip = {
 };
 
 static const struct tps65219_chip_data chip_info_table[] = {
+	[TPS65214] = {
+		.ngpio = 2,
+		.offset = 1,
+	},
 	[TPS65215] = {
 		.ngpio = 2,
 		.offset = 1,
@@ -191,6 +195,7 @@ static int tps65219_gpio_probe(struct platform_device *pdev)
 }
 
 static const struct platform_device_id tps6521x_gpio_id_table[] = {
+	{ "tps65214-gpio", TPS65214 },
 	{ "tps65215-gpio", TPS65215 },
 	{ "tps65219-gpio", TPS65219 },
 	{ }
@@ -207,5 +212,5 @@ static struct platform_driver tps65219_gpio_driver = {
 module_platform_driver(tps65219_gpio_driver);
 
 MODULE_AUTHOR("Jonathan Cormier <jcormier@xxxxxxxxxxxxxxxx>");
-MODULE_DESCRIPTION("TPS65215/TPS65219 GPIO driver");
+MODULE_DESCRIPTION("TPS65214/TPS65215/TPS65219 GPIO driver");
 MODULE_LICENSE("GPL");
@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 /*
- * GPIO driver for TI TPS65215/TPS65219 PMICs
+ * TI TPS65214/TPS65215/TPS65219 PMIC GPIO Driver
  *
  * Copyright (C) 2024 Texas Instruments Incorporated - http://www.ti.com/
-- 
2.43.0





[Index of Archives]     [Linux SPI]     [Linux Kernel]     [Linux ARM (vger)]     [Linux ARM MSM]     [Linux Omap]     [Linux Arm]     [Linux Tegra]     [Fedora ARM]     [Linux for Samsung SOC]     [eCos]     [Linux Fastboot]     [Gcc Help]     [Git]     [DCCP]     [IETF Announce]     [Security]     [Linux MIPS]     [Yosemite Campsites]

  Powered by Linux